@@ -1,25 +1,12 @@
-/*****************************************************************************
- * This file is part of Kiten, a KDE Japanese Reference Tool...              *
- * Copyright (C) 2001 Jason Katz-Brown <jason@katzbrown.com>                 *
- * Copyright (C) 2005 Paul Temple <paul.temple@gmx.net>                      *
- * Copyright (C) 2006 Joseph Kerian <jkerian@gmail.com>                      *
- * Copyright (C) 2006 Eric Kjeldergaard <kjelderg@gmail.com>                 *
- *                                                                           *
- * This program is free software; you can redistribute it and/or modify      *
- * it under the terms of the GNU General Public License as published by      *
- * the Free Software Foundation; either version 2 of the License, or         *
- * (at your option) any later version.                                       *
- *                                                                           *
- * This program is distributed in the hope that it will be useful,           *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
- * GNU General Public License for more details.                              *
- *                                                                           *
- * You should have received a copy of the GNU General Public License         *
- * along with this program; if not, write to the Free Software               *
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 *
- * USA                                                                       *
- *****************************************************************************/
+/*
+    This file is part of Kiten, a KDE Japanese Reference Tool...
+    SPDX-FileCopyrightText: 2001 Jason Katz-Brown <jason@katzbrown.com>
+    SPDX-FileCopyrightText: 2005 Paul Temple <paul.temple@gmx.net>
+    SPDX-FileCopyrightText: 2006 Joseph Kerian <jkerian@gmail.com>
+    SPDX-FileCopyrightText: 2006 Eric Kjeldergaard <kjelderg@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "entrylistmodel.h"
 
@@ -72,12 +59,12 @@ void EntryListModel::setEntryList( const EntryList &list )
 
 int EntryListModel::rowCount( const QModelIndex & parent ) const
 {
-  return _list.size();
+  return parent.isValid() ? 0 : _list.size();
 }
 
 int EntryListModel::columnCount( const QModelIndex & parent ) const
 {
-  return 3;
+  return parent.isValid() ? 0 : 3;
 }
 
 QVariant EntryListModel::data ( const QModelIndex & index, int role ) const
